@@ -87,12 +87,11 @@ callback. The reason is that most event loops are not reentrant and
 this can cause a deadlock at best and corrupt memory at worst.
 
 Coro will try to catch you when you block in the event loop
-("FATAL:$Coro::IDLE blocked itself"), but this is just best effort and
+("FATAL: $Coro::IDLE blocked itself"), but this is just best effort and
 only works when you do not run your own event loop.
 
-To avoid this problem, simply do not block inside an event callback
-- start a new thread (e.g. with C<Coro:async_pool>) or use
-C<Coro::unblock_sub>.
+To avoid this problem, start a new thread (e.g. with C<Coro::async_pool>)
+or use C<Coro::unblock_sub> to run blocking tasks.
 
 =head2 INVERSION OF CONTROL
 
@@ -164,7 +163,7 @@ use common::sense;
 use Coro;
 use AnyEvent ();
 
-our $VERSION = 6.09;
+our $VERSION = 6.29;
 
 #############################################################################
 # idle handler
